@@ -23,7 +23,7 @@ Library: https://docs.python.org/3/library/logging.html
 
 """
 
-import os, logging, yaml, sys, glob, json, traceback, shutil
+import os, logging, yaml, sys, glob, json, traceback, shutil, math
 from pathlib import Path
 import datetime, time
 import teradata, teradatasql #teradatasqlalchemy
@@ -340,8 +340,13 @@ def senderroremail(**kwargs):
     msg['Subject'] = 'Error executing ' + programName_
     msg['From'] = cfg.get('EMAIL').get('reply')
     msg['To'] = cfg.get(kwargs.get('appName')).get('support_email')
+    
     # Send the message via our own SMTP server.
-    s = smtplib.SMTP(cfg.get('EMAIL').get('SMTP'))
+    if  cfg.get('EMAIL').get('SMTP') is not None:
+        s = smtplib.SMTP(cfg.get('EMAIL').get('SMTP'))
+    else:
+        s = smtplib.SMTP(cfg.get('EMAIL').get('smtp'))
+
     s.send_message(msg)
     s.quit()
     
@@ -471,6 +476,57 @@ def fn_execution_timer(_loggerobj):
             return result    
         return wrapper
     return decorator
+
+#Pass in the Database name, Table name  and your dataframe to load it to the table eg: kdsutil.load_df_to_edw('EDW_PRD_SB_KDS','MX_TABLE',df)
+#An optional kwarg is available in case it's not a kill and fill table eg: kdsutil.load_df_to_edw('EDW_PRD_SB_KDS','MX_TABLE',df, purge='N)
+
+def load_df_to_edw(*args, **kwargs):    
+    db  = args[0]
+    table = args[1]
+    df = args[2]
+
+    if  kwargs.get('purge') is not None:
+        if kwargs.get('purge').upper() == 'N' or  kwargs.get('purge').upper() == 'NO':
+            purge = False
+    else:
+        purge = True
+
+    df.drop_duplicates(inplace=True)
+    numcols = df.shape[1]
+    df_lst = [tuple(x) for x in df.values]
+    nRows = len(df)
+    nRowsPerBatch = 2500 if numcols < 50 else 500
+    nBatchCount = math.ceil(nRows/nRowsPerBatch)
+    sTableName = db + '.' + table
+    
+    start = 0
+    finish = nRowsPerBatch
+    
+    conn_edw = get_kds_teradata_conn(**cfg.get('edw'))
+    
+    if purge:   
+        del_str = f"""DELETE FROM {sTableName};"""
+        cursor = conn_edw.cursor()
+        cursor.execute(del_str)            
+    
+    qstr = '?,'
+    itr = 1
+    
+    for q in range(numcols-1):  
+        if itr == numcols-1:
+            qstr += '?'
+            break
+        qstr += '?,'     
+        itr += 1
+            
+    with conn_edw as session:
+        for batch in range(0, nBatchCount):
+            session.executemany(f"""INSERT INTO {sTableName} VALUES ({qstr})"""
+                                , df_lst[start:finish], batch=True)
+            start = start + nRowsPerBatch
+            finish = finish + nRowsPerBatch
+            
+    return 
  
 #################################################################
 # Main function equivalent. 
